@@ -1,8 +1,8 @@
-#!/usr/bin/bash
+#!/bin/bash
 #
 #   libtool.sh - Remove libtool files from the package
 #
-#   Copyright (c) 2013-2020 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2013-2024 Pacman Development Team <pacman-dev@lists.archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,10 +21,10 @@
 [[ -n "$LIBMAKEPKG_TIDY_LIBTOOL_SH" ]] && return
 LIBMAKEPKG_TIDY_LIBTOOL_SH=1
 
-LIBRARY=${LIBRARY:-'/usr/share/makepkg'}
+MAKEPKG_LIBRARY=${MAKEPKG_LIBRARY:-'/usr/share/makepkg'}
 
-source "$LIBRARY/util/message.sh"
-source "$LIBRARY/util/option.sh"
+source "$MAKEPKG_LIBRARY/util/message.sh"
+source "$MAKEPKG_LIBRARY/util/option.sh"
 
 
 packaging_options+=('libtool')
